#pragma W_MAC_REDEF-
#pragma W_FUNC_PROC-
#pragma W_INDIRECT-

#include MKSTRING.HDR
#include MKSTATUS.HDR
#include MKMISC.HDR
#include MKTIME.HDR
#include MKFILE.HDR
#include COLORS.HDR
#include SYSTEM.HDR
#include STRING.HDR
#include SCREEN.HDR
#include DATE.HDR
#include IO.HDR

VARDEF EXTERN
   BYTE        __color_std
ENDDEF

VARDEF
   LOGICAL     use_scrn_save  = .T.
   LOGICAL     use_log_file   = .F.
   LOGICAL     use_color      = .T.
   LOGICAL     scrn_saved     = .F.
   UINT        sec_scrn_save  = 180
   ULONG       task_list      = 0
   CHAR( 128 ) log_file       = ""
   CHAR( 08 )  end_time       = ""
   CHAR( 05 )  last_exec      = "     "
   CHAR( 12 )  crn_file       = "MKCRON.CRN"
   BYTE        palette[5]     = &BLUE_WHITE, &RED_YELLOW, &BLUE_LIGHT_GREY
ENDDEF

PROCEDURE CronFile PROTOTYPE
PROCEDURE CronScrn PROTOTYPE
PROCEDURE CronUserScrn PROTOTYPE
PROCEDURE CronMain PROTOTYPE
PROCEDURE CronParam PROTOTYPE

 ******************************************************************************
 *									      *
 *  Programm	    : MKCRON V1.0			  (C) 1992 Kalkhoff   *
 *  Modul	    : CRONCLOCK                                               *
 *  Autor           : M.T. Kalkhoff					      *
 *  letzte nderung : 07.09.1992					      *
 *									      *
 *  Aufgabe         : Diese Routine wird bei Programmbeginn einmalig aufgeru- *
 *                    fen. Sinn ist es, alle bentigten Uhren zu formatieren  *
 *                    und anschlieend einzuschalten.                         * 
 *									      *
 ******************************************************************************
PROCEDURE CronClock

   * erst mal den Uhrtreiber installieren ...

   InstallClock()

   * Das ist die Standarduhr mit der fortlaufenden Uhrzeit ...

   SetClockFormat( 0, &HHMMSS_24 )
   SetClockRowCol( 0, 5, 66 )
   SetClockAttr( 0, palette[0] )
   ShowClock( 0 )

   * Bei aktiviertem SCREEN SAVER wird mit der nchsten Uhr der Countdown,
   * sprich die Restsekunden, eingeleitet und angezeigt ...

   IF use_scrn_save

      SetClockFormat( 1, &COUNTDOWN )
      SetClockRowCol( 1, 11, 66 )
      SetCounter( 1, sec_scrn_save )
      SetClockAttr( 1, palette[0] )
      ShowClock( 1 )

   ENDIF

   * Die letzte Uhr in der Fuzeile definiert die Programmlaufzeit. Aller-
   * dings ist einschrnkend zu erwhnen, da diese nach einer Programmaus-
   * fhrung wieder den Wert NULL annimmt.

   SetClockFormat( 2, &ELAPSED )
   SetClockRowCol( 2, 24, 70 )
   SetClockAttr( 2, palette[1] )   
   ShowClock( 2 )

ENDPRO

 ******************************************************************************
 *									      *
 *  Programm	    : MKCRON V1.0			  (C) 1992 Kalkhoff   *
 *  Modul	    : CRONCONFIG                                              *
 *  Autor           : M.T. Kalkhoff					      *
 *  letzte nderung : 07.09.1992					      *
 *									      *
 *  Aufgabe         : Konfiguration diverser Systemeinstellungen.             *
 *									      *
 ******************************************************************************
PROCEDURE CronConfig

   * dieser Part ist fr Perverse oder dem Monochrome Modus gewidmet ...

   IF .NOT. use_color
      palette[0] = &BLACK_WHITE
      palette[1] = &WHITE_BLACK
      palette[2] = &BLACK_LIGHT_GREY
   ENDIF

   * und noch ein paar Standardeinstellungen ...

   Cursor_Off()
   SetDate( &DATE_GERMAN )
   Scrn_Direct()
   Key_Dos()

   __color_std = palette[0]
   last_exec   = Left( Time(), 5 )

ENDPRO

 ******************************************************************************
 *									      *
 *  Programm	    : MKCRON V1.0			  (C) 1992 Kalkhoff   *
 *  Modul	    : FCO_END                                                 *
 *  Autor           : M.T. Kalkhoff					      *
 *  letzte nderung : 07.09.1992					      *
 *									      *
 *  Aufgabe         : Seitens des FCO/Force Systems wird die folgende Routine *
 *                    automatisch zum Programmende hin aufgerufen. Somit kann *
 *                    sichergestellt werden, da der Uhrtreiber auch dein-    *
 *                    stalliert wird !!!                                      *
 *									      *
 ******************************************************************************
PROCEDURE Fco_End

   DeInstallClock()

ENDPRO

 ******************************************************************************
 *									      *
 *  Programm	    : MKCRON V1.0			  (C) 1992 Kalkhoff   *
 *  Modul	    : CRONERROR                                               *
 *  Autor           : M.T. Kalkhoff					      *
 *  letzte nderung : 07.09.1992					      *
 *									      *
 *  Aufgabe         : Ausgabe einer Fehlermeldung und evtl. Programmabbruch.  *
 *									      *
 ******************************************************************************
PROCEDURE CronError
   PARAMETERS CONST CHAR    mess, ;
              VALUE LOGICAL fatal

   Sound( 400, 2 )
   ? mess 
   Sound( 200, 4 )

   IF fatal
      QUIT
   ENDIF

ENDPRO

 ******************************************************************************
 *									      *
 *  Programm	    : MKCRON V1.0			  (C) 1992 Kalkhoff   *
 *  Modul	    : MAIN					              *
 *  Autor           : M.T. Kalkhoff					      *
 *  letzte nderung : 07.09.1992					      *
 *									      *
 *  Aufgabe         : Hauptroutine des CRON (short, wah ???)                  *
 *									      *
 ******************************************************************************
PROCEDURE Fco_Main

   * Parameter unbedingt zuerst bernehmen !!!

   CronParam()

   * Das Bildschirmlschen wurde ber DOS gewhlt, damit auch das korrekte
   * Farbattribut verwandt wird ...

   RUN GetEnv( "COMSPEC" ) + " /C CLS"

   * Nun noch die restlichen Routinen abarbeiten ...

   CronConfig()
   CronFile()
   CronScrn()
   CronUserScrn()
   CronClock()
   CronMain()

   RUN GetEnv( "COMSPEC" ) + " /C CLS"

ENDPRO